<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-compagnon?lang_cible=lb
// ** ne pas modifier le fichier **

return [

	// C
	'compagnon_description' => 'De Compagnon bitt de Benotzer Hëllef beim éischte Benotze vum privaten Deel vu SPIP.',
	'compagnon_nom' => 'Compagnon',
	'compagnon_slogan' => 'Assistent fir déi éischt Schrëtt mat SPIP',
];
